@@ -77,10 +77,11 @@ def _parse_status(data: bytes) -> Dict[str, Any]:
 
 def _parse_status_bits(status_bits: int) -> Dict[str, Any]:
     # Bitfield
-    # Tracking and interlock are the same bit?
     return {
         "forward_limit_switch": bool(status_bits & 0x1),
         "reverse_limit_switch": bool(status_bits & 0x2),
+        "forward_limit_soft": bool(status_bits & 0x4),
+        "reverse_limit_soft": bool(status_bits & 0x8),
         "moving_forward": bool(status_bits & 0x10),
         "moving_reverse": bool(status_bits & 0x20),
         "jogging_forward": bool(status_bits & 0x40),
@@ -88,11 +89,26 @@ def _parse_status_bits(status_bits: int) -> Dict[str, Any]:
         "motor_connected": bool(status_bits & 0x100),
         "homing": bool(status_bits & 0x200),
         "homed": bool(status_bits & 0x400),
+        "initializing": bool(status_bits & 0x800),
         "tracking": bool(status_bits & 0x1000),
-        "interlock": bool(status_bits & 0x1000),
         "settled": bool(status_bits & 0x2000),
         "motion_error": bool(status_bits & 0x4000),
+        "instrument_error": bool(status_bits & 0x8000),
+        "interlock": bool(status_bits & 0x10000),
+        "overtemp": bool(status_bits & 0x20000),
+        "voltage_fault": bool(status_bits & 0x40000),
+        "commutation_error": bool(status_bits & 0x80000),
+        "digital_in_1": bool(status_bits & 0x100000),
+        "digital_in_2": bool(status_bits & 0x200000),
+        "digital_in_3": bool(status_bits & 0x300000),
+        "digital_in_4": bool(status_bits & 0x400000),
         "motor_current_limit_reached": bool(status_bits & 0x1000000),
+        "encoder_fault": bool(status_bits & 0x2000000),
+        "overcurrent": bool(status_bits & 0x4000000),
+        "current_fault": bool(status_bits & 0x8000000),
+        "power_ok": bool(status_bits & 0x10000000),
+        "active": bool(status_bits & 0x20000000),
+        "error": bool(status_bits & 0x40000000),
         "channel_enabled": bool(status_bits & 0x80000000),
     }
 
@@ -236,7 +252,7 @@ def hw_response(data: bytes) -> Dict[str, Any]:
 
 @parser(0x0081)
 def hw_richresponse(data: bytes) -> Dict[str, Any]:
-    msg_ident, code, notes = struct.unpack_from("<HH64c", data, HEADER_SIZE)
+    msg_ident, code, notes = struct.unpack_from("<HH64s", data, HEADER_SIZE)
     return {"msg_ident": msg_ident, "code": code, "notes": notes}
 
 
